==> static-compat-qt6-declarative-6.7.3-1-x86_64.pkg.tar.zst: usr/static-compat/lib/cmake/Qt6Quick/Qt6QuickTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::Quick" for configuration "Release"
set_property(TARGET Qt6::Quick APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LINK_INTERFACE_MULTIPLICITY_RELEASE "3"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libQt6Quick.a"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick )
list(APPEND _cmake_import_check_files_for_Qt6::Quick "${_IMPORT_PREFIX}/lib/libQt6Quick.a" )

# Import target "Qt6::Quick_resources_1" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/objects-Release/Quick_resources_1/.qt/rcc/qrc_qmake_QtQuick_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_1 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/objects-Release/Quick_resources_1/.qt/rcc/qrc_qmake_QtQuick_init.cpp.o" )

# Import target "Qt6::Quick_resources_2" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_2/.qt/rcc/qrc_scenegraph_shaders_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_2 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_2/.qt/rcc/qrc_scenegraph_shaders_init.cpp.o" )

# Import target "Qt6::Quick_resources_3" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_3 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_3/.qt/rcc/qrc_scenegraph_curve_shaders_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_3 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_3 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_3/.qt/rcc/qrc_scenegraph_curve_shaders_init.cpp.o" )

# Import target "Qt6::Quick_resources_4" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_4 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_4 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_4/.qt/rcc/qrc_scenegraph_curve_shaders_derivatives_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_4 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_4 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_4/.qt/rcc/qrc_scenegraph_curve_shaders_derivatives_init.cpp.o" )

# Import target "Qt6::Quick_resources_5" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_5 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_5 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_5/.qt/rcc/qrc_scenegraph_curve_shaders_lg_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_5 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_5 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_5/.qt/rcc/qrc_scenegraph_curve_shaders_lg_init.cpp.o" )

# Import target "Qt6::Quick_resources_6" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_6 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_6 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_6/.qt/rcc/qrc_scenegraph_curve_shaders_lg_derivatives_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_6 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_6 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_6/.qt/rcc/qrc_scenegraph_curve_shaders_lg_derivatives_init.cpp.o" )

# Import target "Qt6::Quick_resources_7" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_7 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_7 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_7/.qt/rcc/qrc_scenegraph_curve_shaders_rg_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_7 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_7 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_7/.qt/rcc/qrc_scenegraph_curve_shaders_rg_init.cpp.o" )

# Import target "Qt6::Quick_resources_8" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_8 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_8 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_8/.qt/rcc/qrc_scenegraph_curve_shaders_rg_derivatives_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_8 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_8 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_8/.qt/rcc/qrc_scenegraph_curve_shaders_rg_derivatives_init.cpp.o" )

# Import target "Qt6::Quick_resources_9" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_9 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_9 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_9/.qt/rcc/qrc_scenegraph_curve_shaders_cg_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_9 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_9 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_9/.qt/rcc/qrc_scenegraph_curve_shaders_cg_init.cpp.o" )

# Import target "Qt6::Quick_resources_10" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_10 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_10 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_10/.qt/rcc/qrc_scenegraph_curve_shaders_cg_derivatives_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_10 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_10 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_10/.qt/rcc/qrc_scenegraph_curve_shaders_cg_derivatives_init.cpp.o" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> static-compat-qt6-declarative-6.9.3-1-x86_64.pkg.tar.zst: usr/static-compat/lib/cmake/Qt6Quick/Qt6QuickTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::Quick" for configuration "Release"
set_property(TARGET Qt6::Quick APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LINK_INTERFACE_MULTIPLICITY_RELEASE "3"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libQt6Quick.a"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick )
list(APPEND _cmake_import_check_files_for_Qt6::Quick "${_IMPORT_PREFIX}/lib/libQt6Quick.a" )

# Import target "Qt6::Quick_resources_1" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_1 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_1 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/objects-Release/Quick_resources_1/.qt/rcc/qrc_qmake_QtQuick_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_1 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_1 "${_IMPORT_PREFIX}/lib/qt6/qml/QtQuick/objects-Release/Quick_resources_1/.qt/rcc/qrc_qmake_QtQuick_init.cpp.o" )

# Import target "Qt6::Quick_resources_2" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_2 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_2 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_2/.qt/rcc/qrc_scenegraph_shaders_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_2 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_2 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_2/.qt/rcc/qrc_scenegraph_shaders_init.cpp.o" )

# Import target "Qt6::Quick_resources_3" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_3 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_3 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_3/.qt/rcc/qrc_scenegraph_curve_shaders_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_3 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_3 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_3/.qt/rcc/qrc_scenegraph_curve_shaders_init.cpp.o" )

# Import target "Qt6::Quick_resources_4" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_4 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_4 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_4/.qt/rcc/qrc_scenegraph_curve_shaders_derivatives_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_4 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_4 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_4/.qt/rcc/qrc_scenegraph_curve_shaders_derivatives_init.cpp.o" )

# Import target "Qt6::Quick_resources_5" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_5 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_5 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_5/.qt/rcc/qrc_scenegraph_curve_shaders_lg_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_5 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_5 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_5/.qt/rcc/qrc_scenegraph_curve_shaders_lg_init.cpp.o" )

# Import target "Qt6::Quick_resources_6" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_6 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_6 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_6/.qt/rcc/qrc_scenegraph_curve_shaders_lg_derivatives_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_6 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_6 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_6/.qt/rcc/qrc_scenegraph_curve_shaders_lg_derivatives_init.cpp.o" )

# Import target "Qt6::Quick_resources_7" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_7 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_7 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_7/.qt/rcc/qrc_scenegraph_curve_shaders_rg_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_7 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_7 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_7/.qt/rcc/qrc_scenegraph_curve_shaders_rg_init.cpp.o" )

# Import target "Qt6::Quick_resources_8" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_8 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_8 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_8/.qt/rcc/qrc_scenegraph_curve_shaders_rg_derivatives_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_8 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_8 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_8/.qt/rcc/qrc_scenegraph_curve_shaders_rg_derivatives_init.cpp.o" )

# Import target "Qt6::Quick_resources_9" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_9 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_9 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_9/.qt/rcc/qrc_scenegraph_curve_shaders_cg_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_9 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_9 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_9/.qt/rcc/qrc_scenegraph_curve_shaders_cg_init.cpp.o" )

# Import target "Qt6::Quick_resources_10" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_10 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_10 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_10/.qt/rcc/qrc_scenegraph_curve_shaders_cg_derivatives_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_10 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_10 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_10/.qt/rcc/qrc_scenegraph_curve_shaders_cg_derivatives_init.cpp.o" )

# Import target "Qt6::Quick_resources_11" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_11 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_11 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_11/.qt/rcc/qrc_scenegraph_curve_shaders_tf_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_11 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_11 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_11/.qt/rcc/qrc_scenegraph_curve_shaders_tf_init.cpp.o" )

# Import target "Qt6::Quick_resources_12" for configuration "Release"
set_property(TARGET Qt6::Quick_resources_12 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(Qt6::Quick_resources_12 PROPERTIES
  IMPORTED_COMMON_LANGUAGE_RUNTIME_RELEASE ""
  IMPORTED_OBJECTS_RELEASE "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_12/.qt/rcc/qrc_scenegraph_curve_shaders_tf_derivatives_init.cpp.o"
  )

list(APPEND _cmake_import_check_targets Qt6::Quick_resources_12 )
list(APPEND _cmake_import_check_files_for_Qt6::Quick_resources_12 "${_IMPORT_PREFIX}/lib/objects-Release/Quick_resources_12/.qt/rcc/qrc_scenegraph_curve_shaders_tf_derivatives_init.cpp.o" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
